@@ -8,11 +8,11 @@ pub use csml_interpreter::{
     },
     load_components,
 };
+
 use serde_json::json;
 
-mod db_connectors;
 mod error_messages;
-
+mod db_connectors;
 mod encrypt;
 mod init;
 mod interpreter_actions;
@@ -345,6 +345,25 @@ pub fn validate_bot(mut bot: CsmlBot) -> CsmlResult {
     csml_interpreter::validate_bot(&bot)
 }
 
+/**
+ * fold CSML bot in one single flow.
+ * Rename all existing steps, goto and functions in order to match their origin flow.
+ * Examples:
+ *  step_name: -> flow_name_step_name:
+ *  goto step_name -> goto flow_name_step_name
+ */
+pub fn fold_bot(mut bot: CsmlBot) -> Result<String, EngineError> {
+    // load native components into the bot
+    bot.native_components = match load_components() {
+        Ok(components) => Some(components),
+        Err(err) => {
+            return Err(EngineError::Parring(err.format_error()))
+        }
+    };
+
+    Ok(csml_interpreter::fold_bot(&bot))
+}
+
 /**
  * Close any open conversation a given client may currently have.
  * We also need to both clean the hold/local memory state to make sure
@@ -463,6 +482,13 @@ pub fn get_status() -> Result<serde_json::Value, EngineError> {
     Ok(serde_json::json!(status))
 }
 
+/**
+ * Make migrations for PgSQL and do nothing for MongoDB and DynamoDB
+ */
+pub fn make_migrations() -> Result<(), EngineError> {
+    db_connectors::make_migrations()
+}
+
 /**
  * delete expired data
  */
